##  Dashboard Details
To navigate to the dashboard details page, click the three-dot icon on the dashboard, then select Dashboard Details. Here, you can view the dashboard details and, if you have the corresponding permissions, update them.
